@@ -246,20 +246,22 @@ fn bootstrap_ipc(token: String, config: &ProcConfig) {
         init_panic_hook(config.backtrace_capture());
     }
 
-    let connection_bootstrap: IpcSender<IpcSender<MarshalledCall>> = match IpcSender::connect(token)
     {
-        Ok(sender) => sender,
-        Err(err) => {
-            if !is_benign_bootstrap_error(&err) {
-                Err::<(), _>(err).expect("could not bootstrap ipc connection");
-            }
-            process::exit(1);
-        }
-    };
-    let (tx, rx) = ipc::channel().unwrap();
-    connection_bootstrap.send(tx).unwrap();
-    let marshalled_call = rx.recv().unwrap();
-    marshalled_call.call(config.panic_handling);
+        let connection_bootstrap: IpcSender<IpcSender<MarshalledCall>> =
+            match IpcSender::connect(token) {
+                Ok(sender) => sender,
+                Err(err) => {
+                    if !is_benign_bootstrap_error(&err) {
+                        Err::<(), _>(err).expect("could not bootstrap ipc connection");
+                    }
+                    process::exit(1);
+                }
+            };
+        let (tx, rx) = ipc::channel().unwrap();
+        connection_bootstrap.send(tx).unwrap();
+        let marshalled_call = rx.recv().unwrap();
+        marshalled_call.call(config.panic_handling);
+    }
     process::exit(0);
 }
 
@@ -317,7 +319,7 @@ impl MarshalledCall {
 unsafe fn run_func<A, R>(
     lib_name: &OsStr,
     fn_offset: isize,
-    recv: OpaqueIpcReceiver,
+    args_recv: OpaqueIpcReceiver,
     sender: OpaqueIpcSender,
     panic_handling: bool,
 ) where
@@ -326,7 +328,7 @@ unsafe fn run_func<A, R>(
 {
     let lib_offset = find_shared_library_offset_by_name(lib_name) as isize;
     let function: fn(A) -> R = mem::transmute(fn_offset + lib_offset as *const () as isize);
-    let args = recv.to().recv().unwrap();
+    let args = args_recv.to().recv().unwrap();
     let rv = if panic_handling {
         reset_panic_info();
         match panic::catch_unwind(panic::AssertUnwindSafe(|| function(args))) {
