@@ -311,10 +311,11 @@ impl Builder {
         let (_rx, tx) = server.accept()?;
 
         let (args_tx, args_rx) = ipc::channel()?;
-        let (return_tx, return_rx) = ipc::channel::<Result<R, PanicInfo>>()?;
-        args_tx.send(args)?;
+        let (return_tx, return_rx) = ipc::channel()?;
 
         tx.send(MarshalledCall::marshal::<A, R>(func, args_rx, return_tx))?;
+        args_tx.send(args)?;
+
         Ok(ProcessHandle {
             recv: return_rx,
             state: Arc::new(ProcessHandleState::new(Some(process.id()))),
@@ -362,15 +363,10 @@ pub struct ProcessHandle<T> {
     pub(crate) state: Arc<ProcessHandleState>,
 }
 
-fn is_ipc_timeout(err: &ipc_channel::Error) -> bool {
-    if let ipc_channel::ErrorKind::Io(ref io) = &**err {
-        match io.kind() {
-            io::ErrorKind::TimedOut => true,
-            io::ErrorKind::WouldBlock => true,
-            _ => false,
-        }
-    } else {
-        false
+fn is_ipc_timeout(err: &ipc_channel::ipc::TryRecvError) -> bool {
+    match err {
+        ipc_channel::ipc::TryRecvError::Empty => true,
+        _ => false,
     }
 }
 
